@@ -1,5 +1,8 @@
-#include "obgnome.h"
 #include <gnome.h>
+#include "obgnome.h"
+#include "obgnome-hello-canvas.h"
+
+
 
 GnomeUIInfo filemenu[] = {
   {GNOME_APP_UI_ITEM, N_("Properties"), N_("Prop Box test"), "propbox",
@@ -91,6 +94,10 @@ box. cool. useful? no :P -Michael */
 }
 @end
 
+
+
+
+// Main window
 @interface HelloWindow : Gnome_AppWin
 {
 id myapp;
@@ -100,6 +107,9 @@ id myapp;
 - buttonClicked1:(id) myObj;
 - buttonClicked2:(id) myObj;
 - buttonClicked3:(id) myObj;
+- buttonClickedForAACanvas:(id) myObj;
+- buttonClickedForCanvas:(id) myObj;
+
 @end
 
 @implementation HelloWindow
@@ -115,7 +125,7 @@ id myapp;
 	self = [super initWithAppWinInfo:"obhello" :"GNOME Obj-C Hello"];
 
 	vbox = [[Gtk_VBox new] show];
-
+	
 	label = [[[Gtk_Label new] initWithLabel:"GNOME is cool. yup."] show];
 	button = [[[Gtk_Button new] initWithLabel:"Font Selection Test"] show];
 	[button connectObj:"clicked" :self];
@@ -156,6 +166,17 @@ id myapp;
 	[button connectObjMethod:"clicked" :self :@selector(buttonClicked3:)];
 	[vbox2 pack_start:button doExpand:TRUE doFill:TRUE doPadding:5];
 
+
+	vbox2 = [[Gtk_HBox new] show];
+	[vbox pack_start:vbox2 doExpand:TRUE doFill:TRUE doPadding:5];
+	button = [[[Gtk_Button new] initWithLabel:"Show a Great Canvas"] show];
+	[button connectObjMethod:"clicked" :self :@selector(buttonClickedForCanvas:)];
+	[vbox2 pack_start:button doExpand:TRUE doFill:TRUE doPadding:5];
+
+	button = [[[Gtk_Button new] initWithLabel:"Show a Great AntiAliased Canvas"] show];
+	[button connectObjMethod:"clicked" :self :@selector(buttonClickedForAACanvas:)];
+	[vbox2 pack_start:button doExpand:TRUE doFill:TRUE doPadding:5];
+
 	[self create_menus:mainmenu];
 	[self set_contents:vbox];
 	[self connect:"delete_event"];
@@ -181,6 +202,28 @@ id myapp;
 	return self;
 }
 
+- buttonClickedForAACanvas:(id) myObj
+{
+  Gnome_Hello_Canvas_Window *canvasWindow;
+  
+  
+  canvasWindow = [ [Gnome_Hello_Canvas_Window alloc] initWithAA:1 ];
+  [canvasWindow show];
+  
+  return self;
+}
+
+- buttonClickedForCanvas:(id) myObj
+{
+  Gnome_Hello_Canvas_Window *canvasWindow;
+  
+  
+  canvasWindow = [ [Gnome_Hello_Canvas_Window alloc] initWithAA:0 ];
+  [canvasWindow show];
+  
+  return self;
+}
+
 - clicked:(id) myObj
 {
 	id hi;
@@ -197,11 +240,11 @@ id myapp;
 	return self;
 }
 
-#define VERSION "0.0.1"
+#define VERSION "0.0.2"
 
 - about:(id) myObj
 {
-	char *author[] = {"Michael Hanni <mhanni@sprintmail.com>", NULL};
+	char *author[] = {"Michael Hanni <mhanni@sprintmail.com>", "Bertrand Guiheneuf <Bertrand.Guiheneuf@inria.fr>", NULL};
 
 	[[[Gnome_About alloc] initWithAboutInfo:"obHello" 
 		version:VERSION 
@@ -243,7 +286,7 @@ HelloObject *window;
 	:(int) argc
 	:(char **) argv
 {
-	self = [super initApp:app_id :NULL :argc :argv :0 :NULL];
+	self = [super initApp:app_id :VERSION :argc :argv];
 
 	window = [[[HelloWindow alloc] initForApp:self] show];
 
