@@ -64,6 +64,7 @@
 #include <obgtk/obgtkPacker.h>
 #include <obgtk/obgtkPaned.h>
 #include <obgtk/obgtkPixmap.h>
+#include <obgtk/obgtkPlug.h>
 #include <obgtk/obgtkPreview.h>
 #include <obgtk/obgtkProgress.h>
 #include <obgtk/obgtkProgressBar.h>
@@ -75,6 +76,7 @@
 #include <obgtk/obgtkScrollbar.h>
 #include <obgtk/obgtkScrolledWindow.h>
 #include <obgtk/obgtkSeparator.h>
+#include <obgtk/obgtkSocket.h>
 #include <obgtk/obgtkSpinButton.h>
 #include <obgtk/obgtkTable.h>
 #include <obgtk/obgtkTearoffMenuItem.h>
