@@ -11,7 +11,7 @@
 }
 
 - castGtkAccelLabel:(GtkAccelLabel *) castitem;
-- (guint) accelerator_width;
+- (guint) get_accelerator_width;
 - set_accel_widget:(id) accel_widget;
 - (gboolean) refetch;
 @end
