@@ -1,4 +1,4 @@
-#include "obgtk.h"
+#include "obgtkAlignment.h"
 
 @implementation Gtk_Alignment
 - init
