@@ -15,19 +15,19 @@
 		   :(gint) tree_column;
 - initWithCTreeInfoTitles:(gint) ncolumns
 			 :(gint) tree_column
-		   Titles:(char **) titles;
+		   Titles:(const gchar **) titles;
 
-- (GtkCTreeNode *)insert:(GtkCTreeNode *) parent
-		 :(GtkCTreeNode *) sibling
-		 :(gchar **) text
-		 :(guint8) spacing
-		 :(GdkPixmap *) pixmap_closed
-		 :(GdkBitmap *) mask_closed
-		 :(GdkPixmap *) pixmap_opened
-		 :(GdkBitmap *) mask_opened
-		 :(gboolean) is_leaf
-		 :(gboolean) expanded;
-- remove:(GtkCTreeNode *) node;
+- (GtkCTreeNode *)insert_node:(GtkCTreeNode *) parent
+                             :(GtkCTreeNode *) sibling
+			     :(gchar **) text
+			     :(guint8) spacing
+			     :(GdkPixmap *) pixmap_closed
+			     :(GdkBitmap *) mask_closed
+			     :(GdkPixmap *) pixmap_opened
+			     :(GdkBitmap *) mask_opened
+			     :(gboolean) is_leaf
+			     :(gboolean) expanded;
+- remove_node:(GtkCTreeNode *) node;
 /* XXX TODO: lots of iterator functions missing here - need to find
    a nice way to map into ObjC */
 - move:(GtkCTreeNode *) node
