@@ -18,7 +18,7 @@
 			 :(gint) tree_column
 		   Titles:(const gchar **) titles
 {
-  return [self castGtkCTree:GTK_CTREE(gtk_ctree_new_with_titles(ncolumns, tree_column, titles))];
+  return [self castGtkCTree:GTK_CTREE(gtk_ctree_new_with_titles(ncolumns, tree_column, (char **)titles))];
 }
 
 - (GtkCTreeNode *)insert_node:(GtkCTreeNode *) parent
