@@ -9,8 +9,7 @@
 {
 @public
   GtkDialog *gtkdialog;
-  Gtk_VBox *vbox;
-  Gtk_HBox *action_area;
+  id vbox, action_area; 
 }
 - castGtkDialog:(GtkDialog *)castitem;
 @end
