@@ -29,7 +29,7 @@
 	 menuLabel:(id) menu_label
 	   pagePos:(gint) position;
 - remove_page:(gint) page_num;
-- (gint) current_page;
+- (gint) get_current_page;
 - set_page:(gint) page_num;
 - next_page;
 - prev_page;
