@@ -1,7 +1,7 @@
 #include "obgtkTearoffMenuItem.h"
 
 @implementation Gtk_TearoffMenuItem
-- castGtkTearoffMenuItem:(GtkMenuItem *) castitem
+- castGtkTearoffMenuItem:(GtkTearoffMenuItem *) castitem
 {
   gtktearoffmenuitem = castitem;
 
