@@ -12,25 +12,24 @@
 }
 
 - castGtkToolbar:(GtkToolbar *)castitem;
-- init;
 - initWithToolbarInfo:(GtkOrientation) orientation
 		     :(GtkToolbarStyle) style;
 - append_item:(const char *) text
 	     :(const char *) tooltip_text
 	     :(const char *) private_tooltip_text
-	     :(Gtk_Widget *) icon
+	     :(id) icon
 	     :(GtkSignalFunc) callback
 	     :(gpointer) user_data;
 - prepend_item:(const char *) text
 	      :(const char *) tooltip_text
 	      :(const char *) private_tooltip_text
-	      :(Gtk_Widget *) icon
+	      :(id) icon
 	      :(GtkSignalFunc) callback
 	      :(gpointer) user_data;
 - insert_item:(const char *) text
 	     :(const char *) tooltip_text
 	     :(const char *) private_tooltip_text
-	     :(Gtk_Widget *) icon
+	     :(id) icon
 	     :(GtkSignalFunc) callback
 	     :(gpointer) user_data
 	     :(gint) position;
@@ -40,6 +39,7 @@
 - set_orientation:(GtkOrientation) orientation;
 - set_style:(GtkToolbarStyle) style;
 - set_tooltips:(BOOL) enable;
+- set_space_size:(gint) space_size;
 @end
 
 #endif /* OBGTK_HBOX_H */
