@@ -3,8 +3,13 @@
 
 #include <obgtk/obgtkObject.h>
 #include <gtk/gtkwidget.h>
+#include <gtk/gtkfeatures.h>
 
+#ifdef GTK_HAVE_FEATURES_1_1_0
+@class Gtk_AccelGroup;
+#else
 @class Gtk_AcceleratorTable;
+#endif
 
 @interface Gtk_Widget : Gtk_Object
 {
@@ -24,13 +29,20 @@
 - draw:(GdkRectangle *) area;
 - draw_focus;
 - draw_default;
-- draw_children;
 - size_request:(GtkRequisition *) requisition;
 - size_allocate:(GtkAllocation *) allocation;
+#ifdef GTK_HAVE_FEATURES_1_1_0
+- add_accelerator:(gchar *)asignal
+		 :(Gtk_AccelGroup *) group
+	   keySym:(gchar)akey
+      modifierSet:(guint8)modifiers
+		 :(GtkAccelFlags)accel_flags;
+#else
 - install_accelerator:(Gtk_AcceleratorTable *) table
 	   signalName:(gchar *)asignal
 	       keySym:(gchar)akey
 	  modifierSet:(guint8)modifiers;
+#endif
 - (gint)event:(GdkEvent *)event;
 - activate;
 - reparent:(Gtk_Widget *) new_parent;
@@ -38,7 +50,6 @@
    locY:(gint)y;
 - (gint) intersect: area:(GdkRectangle *)anArea
       intersection:(GdkRectangle *)aRectangle;
-- (gint) basic;
 - grab_focus;
 - grab_default;
 - set_name:(gchar *)name;
