@@ -1,5 +1,9 @@
 #include "obgtkWidget.h"
+#ifdef GTK_HAVE_FEATURES_1_1_0
+#include "obgtkAccelGroup.h"
+#else
 #include "obgtkAcceleratorTable.h"
+#endif
 
 @implementation Gtk_Widget
 - castGtkWidget:(GtkWidget *)castitem
@@ -78,11 +82,6 @@
   return self;
 }
 
-- draw_children
-{
-  gtk_widget_draw_children(gtkwidget);
-  return self;
-}
 
 - size_request:(GtkRequisition *)requisition
 {
@@ -96,6 +95,22 @@
   return self;
 }
 
+#ifdef GTK_HAVE_FEATURES_1_1_0
+- add_accelerator:(gchar *)asignal
+		 :(Gtk_AccelGroup *) group
+	   keySym:(gchar)akey
+      modifierSet:(guint8)modifiers
+		 :(GtkAccelFlags)accel_flags
+{
+  gtk_widget_add_accelerator(gtkwidget,
+			     asignal,
+			     group->gtkaccelgroup,
+			     akey,
+			     modifiers,
+			     accel_flags);
+  return self;
+}
+#else
 - install_accelerator:(Gtk_AcceleratorTable *) table
 	   signalName:(gchar *)asignal
 	       keySym:(gchar)akey
@@ -108,6 +123,7 @@
 				 modifiers);
   return self;
 }
+#endif
 
 - (gint)event:(GdkEvent *)event
 {
@@ -141,11 +157,6 @@
   return gtk_widget_intersect(gtkwidget, anArea, aRectangle);
 }
 
-- (gint)basic
-{
-  return gtk_widget_basic(gtkwidget);
-}
-
 - grab_focus
 {
   gtk_widget_grab_focus(gtkwidget);
